@@ -37,7 +37,7 @@ class DjangoMemcacheWrapper(object):
 # Check if django is using memcache as the cache backend. If so, wrap the
 # cache object in a DjangoMemcacheWrapper for Django < 1.2 that fixes a bug
 # with retrieving pickled data.
-from django.core.cache.backends.base import InvalidCacheBackendError
+from django.core.cache.backends.base import InvalidCacheBackendError  # noqa
 try:
     from django.core.cache.backends.memcached import CacheClass
 except (ImportError, AttributeError, InvalidCacheBackendError):
