@@ -15,9 +15,9 @@ ev = events.events(app=app)
 
 class Command(CeleryCommand):
     """Run the celery curses event viewer."""
-    options = (CeleryCommand.options
-               + ev.get_options()
-               + ev.preload_options)
+    options = (CeleryCommand.options +
+               ev.get_options() +
+               ev.preload_options)
     help = 'Takes snapshots of the clusters state to the database.'
 
     def handle(self, *args, **options):
