@@ -4,7 +4,7 @@ try:
     from django.conf.urls import (patterns, include, url,
                                   handler500, handler404)
 except ImportError:
-    from django.conf.urls import (patterns, include, url,  # noqa
+    from django.conf.urls.defaults import (patterns, include, url,  # noqa
                                   handler500, handler404)
 from django.contrib import admin
 
