@@ -3,7 +3,7 @@
 This module is an alias to :mod:`kombu.transport.django`
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import kombu.transport.django as transport
 
