@@ -75,8 +75,13 @@ try:
 
 except ImportError:
     now = datetime.now
-    make_aware = make_naive = lambda x: x
-    is_aware = lambda x: False
+
+    def _pass(x):
+        return x
+    make_aware = make_naive = _pass
+
+    def is_aware(x):
+        return False
 
 
 def maybe_make_aware(value):
@@ -93,3 +98,10 @@ def is_database_scheduler(scheduler):
     from kombu.utils import symbol_by_name
     from .schedulers import DatabaseScheduler
     return issubclass(symbol_by_name(scheduler), DatabaseScheduler)
+
+
+def fromtimestamp(value):
+    if getattr(settings, 'CELERY_ENABLE_UTC', False):
+        return datetime.utcfromtimestamp(value)
+    else:
+        return datetime.fromtimestamp(value)
