@@ -7,12 +7,12 @@ import os
 # is relative to the documentation root, use os.path.abspath to make it
 # absolute, like shown here.
 sys.path.insert(0, os.getcwd())
-import django
+import django  # noqa
 os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'settings')
 if django.VERSION < (1, 4):
     from django.core.management import setup_environ
     setup_environ(__import__(os.environ['DJANGO_SETTINGS_MODULE']))
-import djcelery
+import djcelery  # noqa
 
 # General configuration
 # ---------------------
@@ -80,7 +80,7 @@ html_sidebars = {
            'sourcelink.html', 'searchbox.html'],
 }
 
-### Issuetracker
+# ## Issuetracker
 issuetracker = 'github'
 issuetracker_project = 'celery/django-celery'
 issuetracker_issue_pattern = r'[Ii]ssue #(\d+)'
