@@ -1,17 +1,17 @@
 # Django settings for testproj project.
 
+import os
+import sys
 import warnings
 warnings.filterwarnings(
     'error', r'DateTimeField received a naive datetime',
     RuntimeWarning, r'django\.db\.models\.fields')
 
-import os
-import sys
 # import source code dir
 sys.path.insert(0, os.getcwd())
 sys.path.insert(0, os.path.join(os.getcwd(), os.pardir))
 
-import djcelery
+import djcelery  # noqa
 djcelery.setup_loader()
 
 NO_NOSE = os.environ.get('DJCELERY_NO_NOSE', False)
